﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

using System.IO;
using Newtonsoft.Json;

namespace EasyConfig.Settings
{
    public static class SettingsLib
    {
        public const string SETTINGS_FILE_NAME = "site_settings.config";

        /// <summary>
        /// Gets the current Settings object from the settings store
        /// </summary>
        /// <returns>Settings object</returns>
        public static SettingsStore GetSettings()
        {
            return JsonConvert.DeserializeObject<SettingsStore>(ReadSettingsFile());
        }

        /// <summary>
        /// Saves the settings to the settings store
        /// </summary>
        /// <param name="settings">The current Settings object</param>
        /// <returns></returns>
        public static bool SaveSettings(SettingsStore settings)
        {
            return WriteSettingsFile(JsonConvert.SerializeObject(settings));
        }

        /// <summary>
        /// Reads the json data from the settings file
        /// </summary>
        /// <returns>json string from the file</returns>
        private static string ReadSettingsFile()
        {
            string settings = "{ }";
            string path = GetPath();

            try
            {
                if (File.Exists(path))
                    settings = File.ReadAllText(path);
            }
            catch (Exception) { }

            return settings;
        }

        /// <summary>
        /// Writes the json string to the settings file
        /// </summary>
        /// <param name="json">The json string that represents the Settings object </param>
        /// <returns>True | False if the write was successful</returns>
        static bool WriteSettingsFile(string json)
        {
            string path = GetPath();

            try
            {
                File.WriteAllText(path, json);
                return true;
            }
            catch (Exception) { }

            return false;
        }

        /// <summary>
        /// Returns the full file path to the settings file
        /// </summary>
        /// <returns></returns>
        static string GetPath()
        {
            string path = System.Web.HttpContext.Current.Server.MapPath("~\\app_data");

            if (!path.EndsWith("\\")) path += "\\";

            path = string.Concat(path, "\\", SETTINGS_FILE_NAME);

            return path;
        }
    }

    /// <summary>
    /// Class to hold all of your settings
    /// </summary>
    public class SettingsStore
    {
        public string UploadFolder { get; set; }
        public string EmailErrorsTo { get; set; }
        public string EmailServerHostname { get; set; }
    }
}