﻿Imports System.Collections.Generic
Imports System.Linq
Imports System.Web

Imports System.IO
Imports Newtonsoft.Json

Namespace EasyConfig.Settings
    Public NotInheritable Class SettingsLib

        Private Sub New()
        End Sub

        Public Const SETTINGS_FILE_NAME As String = "site_settings.config"

        ''' <summary>
        ''' Gets the current Settings object from the settings store
        ''' </summary>
        ''' <returns>Settings object</returns>
        Public Shared Function GetSettings() As SettingsStore
            Return JsonConvert.DeserializeObject(Of SettingsStore)(ReadSettingsFile())
        End Function

        ''' <summary>
        ''' Saves the settings to the settings store
        ''' </summary>
        ''' <param name="settings">The current Settings object</param>
        ''' <returns></returns>
        Public Shared Function SaveSettings(ByVal settings As SettingsStore) As Boolean
            Return WriteSettingsFile(JsonConvert.SerializeObject(settings))
        End Function

        ''' <summary>
        ''' Reads the json data from the settings file
        ''' </summary>
        ''' <returns>json string from the file</returns>
        Private Shared Function ReadSettingsFile() As String
            Dim settings As String = "{ }"
            Dim path As String = GetPath()

            Try
                If File.Exists(path) Then
                    settings = File.ReadAllText(path)
                End If
            Catch ex As Exception
            End Try

            Return settings
        End Function

        ''' <summary>
        ''' Writes the json string to the settings file
        ''' </summary>
        ''' <param name="json">The json string that represents the Settings object </param>
        ''' <returns>True | False if the write was successful</returns>
        Private Shared Function WriteSettingsFile(ByVal json As String) As Boolean
            Dim path As String = GetPath()

            Try
                File.WriteAllText(path, json)
                Return True
            Catch ex As Exception
            End Try

            Return False
        End Function

        ''' <summary>
        ''' Returns the full file path to the settings file
        ''' </summary>
        ''' <returns></returns>
        Private Shared Function GetPath() As String
            Dim path As String = System.Web.HttpContext.Current.Server.MapPath("~\app_data")

            If Not path.EndsWith("\") Then
                path += "\"
            End If

            path = String.Concat(path, "\", SETTINGS_FILE_NAME)

            Return path
        End Function
    End Class

    ''' <summary>
    ''' Class to hold all of your settings
    ''' </summary>
    Public Class SettingsStore

        Public Property UploadFolder() As String
        Public Property EmailErrorsTo() As String
        Public Property EmailServerHostname() As String
    End Class
End Namespace